==> ugly-autodelete-1.0.tar: ugly-autodelete-1.0/autodelete.sh <==
#!/bin/bash

                         ##                        ##
                        ##  autodelete 1.0 by ugly  ##
                         ##                        ##


free_limit="8000"           # If set, the script will not delete anything unless
                            # the amount of free space on a disk drops below the
                            # amount, in MBs, that you specify.  Applies to
                            # all disks that you specify in the various paths
                            # below.
                            #
                            # Set to "" to disable this function.

debug="YES"                  # If set to "YES", the script will echo the rm
                            # commands, but not actually delete any files.

dated_day_format="%m%d"     # leave these set to default values if you don't
dated_week_format="WEEK%V"  # have dated dirs - read 'man date' for syntax

### STATIC PATHS                                 ###
###   Syntax: <dev> <path> <limit in MBs>        ###
###                                              ###
### You can add as many paths as needed.  Just   ###
### follow the examples below.  <dev> is         ###
### whatever device the path resides or is       ###
### mounted on.                                  ###
###                                              ###
static[0]="/dev/ccd0 /jail/glftpd/site/drive2/divx 147000"
static[1]="/dev/ccd0 /jail/glftpd/site/drive2/xxx 48000"
static[2]="/dev/ar0s1 /jail/glftpd/site/mp3/audiobooks 10000"


### DYNAMIC PATHS                                ###
###   Syntax: <dev> <path> <percentage>          ###
###                                              ###
### Specify the path and the device that         ###
### it resides on, followed by the percentage of ###
### free space the path is allowed to use.  Do   ###
### not specify "100" percent or else the script ###
### will never delete anything from the path.    ###
###                                              ###
### You may specify more than one path per       ###
### device, but not per line!  For example:      ###
###                                              ###
###   dynamic[0]="/dev/hda1 /glftpd/site/mp3 45" ###
###   dynamic[1]="/dev/hda1 /glftpd/site/vcd 45" ###
###                                              ###
### is fine, but                                 ###
###                                              ###
###   dynamic[0]="/dev/hda1 /glftpd/site/mp3 /glftpd/site/vcd 90" ###
###                                              ###
### is not!                                      ###
###                                              ###
### For each dynamic path, specify paths that    ###
### reside on the same device as the dynamic     ###
### path, but not *within* the dynamic path      ###
### itself.  This is so that the percentage of   ###
### used space is calculated correctly.          ###
###                                              ###
### You can specify multiple paths per           ###
### dynamic_subtract variable, i.e.              ###
###                                              ###
### dynamic_subtract[0]="/glftpd/site/one /glftpd/site/two"
###                                              ###
### is fine.                                     ###
###                                              ###
dynamic[0]="/dev/ar0s1 /jail/glftpd/site/mp3/incoming 95"
dynamic_subtract[0]="/jail/glftpd/site/requests /jail/glftpd/site/mp3/audiobooks /jail/glftpd/site/mp3/groups"

dynamic[1]="/dev/ad0s1h /jail/glftpd/site/mv 95"
dynamic_subtract[1]="/jail/glftpd/site/mv/groups"


### DELETE-BY-DATE PATHS                         ###
###   Syntax: <path> <age limit in days>         ###
###                                              ###
### *BSD USERS: This portion of the script       ###
### requires that you install sh-utils and       ###
### fileutils from your ports tree!              ###
###                                              ###
date[0]="/dev/ar0s1 /jail/glftpd/site/requests 14"


### EXCEPTIONS:                                  ###
###   Syntax: "<string1>" "<string2>" "<...>"    ###
###                                              ###
### Space separated, quoted list of strings in   ###
### dirs that are never to be deleted.           ###
###                                              ###
### NOTE: Do not use wildcards here.  Simply     ###
###       specifying "_WHATEVER" will exclude    ###
###       "*_WHATEVER*".                         ###
###                                              ###
exceptions=( "_USE_SITE_REQUEST" "_CWD" "groups" "(incomplete)-" )


### END CONFIG ###


if [ `uname` = "Linux" ];
  then
    LS="ls" DATE="date" DU="du"
  else
    LS="/usr/local/bin/gls" DATE="/usr/local/bin/gdate" DU="/usr/local/bin/gdu"
    if [ ! -f "$LS" ] || [ ! -f "$DATE" ] || [ ! -f "$DU" ]; then
      echo "This script requires GNU's versions of ls, date, and du.  Please"
      echo "install sh-utils and fileutils from your ports tree, or download"
      echo "them as part of the coreutils package available from here:"
      echo "http://www.gnu.org/software/coreutils/"
      exit 0
    fi
fi

### FREE (NON-STRICT) MODE ###

if [ ! -z "$free_limit" ]; then

index=0
while [ "$index" -lt ${#static[@]} ];
  do
    dev_item=`echo ${static["$index"]} | awk '{print $1}'`
    dev_freespace=`df -m | grep "$dev_item" | awk '{print $4}'`
    if [ "$dev_freespace" -lt "$free_limit" ]; then
    dev_list=""$dev_list"
      $dev_item"
    fi
    index=$(( $index + 1 ))
done

index=0
while [ "$index" -lt ${#dynamic[@]} ];
  do
    dev_item=`echo ${dynamic["$index"]} | awk '{print $1}'`
    dev_freespace=`df -m | grep "$dev_item" | awk '{print $4}'`
    if [ "$dev_freespace" -lt "$free_limit" ]; then
    dev_list=""$dev_list"
      $dev_item"
    fi
    index=$(( $index + 1 ))
done

index=0
while [ "$index" -lt ${#date[@]} ];
  do
    dev_item=`echo ${date["$index"]} | awk '{print $1}'`
    dev_freespace=`df -m | grep "$dev_item" | awk '{print $4}'`
    if [ "$dev_freespace" -lt "$free_limit" ]; then
    dev_list=""$dev_list"
      $dev_item"
    fi
    index=$(( $index + 1 ))
done

if [ -z "$dev_list" ];
  then
    exit 0
  else
    dev_list=`echo "$dev_list" | uniq`
fi

fi


### GLOBAL TODAY/CURRENT WEEK ###
today=`date +"$dated_day_format"`
this_week=`date +"$dated_week_format"`


### STATIC DELETE ###
index=0
while [ "$index" -lt ${#static[@]} ];
  do
    unset running_list_stat
    dev=`echo ${static["$index"]} | awk '{print $1}'`
    on_devlist=`echo "$dev_list" | grep "$dev"`
    if [[ ! -z "$free_limit" && ! -z "$on_devlist" ]] || [ -z "$free_limit" ]; then
    dir=`echo ${static["$index"]} | awk '{print $2}'`
    limit=`echo ${static["$index"]} | awk '{print $3}'`
    current_size=`$DU -ms "$dir" | awk '{print $1}' | sed -e 's/[^[:digit:]]//g'`
        while [ "$current_size" -gt "$limit" ];
	  do
            if [ "$running_list_stat" = "" ]; then
              if [[ -d "$dir"/"$today" || -d "$dir"/"$this_week" ]];
                then
                  running_list_stat=`ls -1 "$dir"`
                else
                  running_list_stat=`ls -1tr "$dir"`
              fi
	      for o in ${exceptions[@]}; do
	        running_list_stat=`echo "$running_list_stat" | grep -v "$o"`
              done
            fi
            if [ "$debug" = "YES" ];
              then
	        oldest_dir=`echo "$running_list_stat" | head -n 1`
                echo "rm -rf -- "$dir"/"$oldest_dir""
                oldest_dirsize=`$DU -ms "$dir"/"$oldest_dir" | awk '{print $1}'`
                running_list_stat=`echo "$running_list_stat" | grep -v \
                  "$oldest_dir"`
	        current_size=`echo ""$current_size"-"$oldest_dirsize"" | bc -l`
              else
                oldest_dir=`echo "$running_list_stat" | head -n 1`
	        rm -rf -- "$dir"/"$oldest_dir"
                running_list_stat=`echo "$running_list_stat" | grep -v \
                  "$oldest_dir"`
	        current_size=`$DU -ms "$dir" | awk '{print $1}' | sed -e \
	         's/[^[:digit:]]//g'`
            fi
	  done
  fi
  index=$(( $index + 1 ))
done

### DATED DELETE ###

index=0
while [ "$index" -lt ${#date[@]} ]; do

days=`echo ${date["$index"]} | awk '{print $3}'`
seconds=`echo ""$days" * 86400" | bc`
date_dir=`echo ${date["$index"]} | awk '{print $2}'`
dev=`echo ${date["$index"]} | awk '{print $1}'`
on_devlist=`echo "$dev_list" | grep "$dev"`

if [[ ! -z "$free_limit" && ! -z "$on_devlist" ]] || [ -z "$free_limit" ];
  then
    if [[ ! -d "$date_dir"/"$today" && ! -d "$date_dir"/"$this_week" ]]; then
    for dfile in "$date_dir"/*
      do
        unset exempt
        for date_exc in ${exceptions[@]}
          do
            is_datedir_exempt=`echo "$dfile" | grep "$date_exc"`
            if [ ! -z "$is_datedir_exempt" ];
              then
                exempt="YES"
            fi
        done
        if [ -z "$exempt" ];
          then
            current_gnusecs=`$DATE "+%s"`
            gnusecs=`$DATE -r "$dfile" "+%s"`
            age_sec=`echo "$current_gnusecs" - "$gnusecs" | bc`
        fi

        if [ -z "$exempt" ] && [ "$age_sec" -ge "$seconds" ];
          then
            if [ "$debug" = "YES" ];
              then
                echo "rm -rf -- "$dfile""
              else
                rm -rf -- "$dfile"
             fi
         fi
    done
  else
    if [ -d "$date_dir"/"$today" ] || [ -d "$date_dir"/"$this_week" ];
      then
        delete_days=$(( $days + 1 ))
        running_list_date=`ls -1 "$date_dir"`
        if [ -d "$date_dir"/"$today" ]; then
          current_date=`date +"$dated_day_format"`
          date_index=`$DATE --date "-"$delete_days" days" +"$dated_day_format"`
          unit="days"
        else
          current_date=`date +"$dated_week_format"`
          date_index=`$DATE --date "-"$delete_days" days" +"$dated_week_format"`
        fi
        index=0
        while [ "$current_date" != "$date_index" ];
          do
            running_list_date=`echo "$running_list_date" | grep -v "$current_date"`
            if [ "$unit" = "days" ];
              then
                current_date=`$DATE --date "-"$index" days" +"$dated_day_format"`
              else
                current_date=`$DATE --date "-"$index" days" +"$dated_week_format"`
            fi
            index=$(( $index + 1 ))
        done
        for i in ${exceptions[@]}; do
          running_list_date=`echo "$running_list_date" | grep -v "$i"`
        done
        for i in `echo "$running_list_date"`; do
          if [ "$debug" = "YES" ];
            then
              echo "rm -rf -- "$date_dir"/"$i""
            else
              rm -rf -- "$date_dir"/"$i"
          fi
        done
    fi
  fi
fi

index=$(( $index + 1 ))
done


### DYNAMIC DELETE ###

index=0
while [ "$index" -lt ${#dynamic[@]} ];
  do
    dev=`echo ${dynamic["$index"]} | awk '{print $1}'`
    on_devlist=`echo "$dev_list" | grep "$dev"`
    if [[ ! -z "$free_limit" && ! -z "$on_devlist" ]] || [ -z "$free_limit" ]; then
    dynamic_dir=`echo ${dynamic["$index"]} | awk '{print $2}'`
    allowed_percent=`echo ${dynamic["$index"]} | awk '{print $3}'`
    current_size=`du -s "$dynamic_dir" | awk '{print $1}'`
    
    drive_used=`df | grep "$dev" | awk '{print $3}'`
    drive_avail=`df | grep "$dev" | awk '{print $4}'`
    drive_size=`echo ""$drive_used"+"$drive_avail"" | bc`

    # drive size minus the dynamic subtract dirs size
    if [ ${#dynamic_subtract[@]} != "0" ]; then
      dyn_subtract_total=`du -sc ${dynamic_subtract["$index"]} | grep total | \
        awk '{print $1}'`
      drive_size=`echo ""$drive_size"-"$dyn_subtract_total"" | bc -l`
    fi
    current_percent=`echo ""$current_size"/"$drive_size"*100" | bc -l | \
      awk -F "." '{print $1}'`
    if [ "$current_percent" = "" ];
      then
        current_percent="0"
    fi
    while [ "$current_percent" -gt "$allowed_percent" ];
      do
        if [ "$running_list_dyn" = "" ]; then
          if [[ -d "$dynamic_dir"/"$today" || -d "$dynamic_dir"/"$this_week" ]];
            then
              running_list_dyn=`ls -1 "$dynamic_dir"`
            else
              running_list_dyn=`ls -1tr "$dynamic_dir"`
          fi
          for u in ${exceptions[@]}; do
            running_list_dyn=`echo "$running_list_dyn" | grep -v "$u"`
          done
        fi
	if [ "$debug" = "YES" ];
	  then
            oldest_dynamic_dir=`echo "$running_list_dyn" | head -n 1`
            echo "rm -rf -- "$dynamic_dir"/"$oldest_dynamic_dir""
            running_list_dyn=`echo "$running_list_dyn" | grep -v \
              "$oldest_dynamic_dir"`
            oldest_dynamic_dir_size=`du \
              -s "$dynamic_dir"/"$oldest_dynamic_dir" | awk '{print $1}'`
             current_size=`echo ""$current_size"-"$oldest_dynamic_dir_size"" | \
               bc -l`
	  else
            oldest_dynamic_dir=`echo "$running_list_dyn" | head -n 1`
            rm -rf -- "$dynamic_dir"/"$oldest_dynamic_dir"
            running_list_dyn=`echo "$running_list_dyn" | grep -v \
              "$oldest_dynamic_dir"`
            current_size=`du -s "$dynamic_dir" | awk '{print $1}'`
	fi
        current_percent=`echo ""$current_size"/"$drive_size"*100" | bc -l | \
         awk -F "." '{print $1}'`
        # because percentages less than 1% will not show up
        if [ -z "$current_percent" ]; then
          current_percent="0"
        fi
      done
  fi
  index=$(( $index + 1 ))
done


exit 0

==> ugly-autodelete-1.0.1.tar: ugly-autodelete-1.0.1/autodelete.sh <==
#!/bin/bash

                         ##                          ##
                        ##  autodelete 1.0.1 by ugly  ##
                         ##                          ##


free_limit="8000"           # If set, the script will not delete anything unless
                            # the amount of free space on a disk drops below the
                            # amount, in MBs, that you specify.  Applies to
                            # all disks that you specify in the various paths
                            # below.
                            #
                            # Set to "" to disable this function.

debug="NO"                  # If set to "YES", the script will echo the rm
                            # commands, but not actually delete any files.

dated_day_format="%m%d"     # leave these set to default values if you don't
dated_week_format="WEEK%V"  # have dated dirs - read 'man date' for syntax

### STATIC PATHS                                 ###
###   Syntax: <dev> <path> <limit in MBs>        ###
###                                              ###
### You can add as many paths as needed.  Just   ###
### follow the examples below.  <dev> is         ###
### whatever device the path resides or is       ###
### mounted on.                                  ###
###                                              ###
static[0]="/dev/ccd0 /jail/glftpd/site/drive2/divx 147000"
static[1]="/dev/ccd0 /jail/glftpd/site/drive2/xxx 48000"
static[2]="/dev/ar0s1 /jail/glftpd/site/mp3/audiobooks 10000"


### DYNAMIC PATHS                                ###
###   Syntax: <dev> <path> <percentage>          ###
###                                              ###
### Specify the path and the device that         ###
### it resides on, followed by the percentage of ###
### free space the path is allowed to use.  Do   ###
### not specify "100" percent or else the script ###
### will never delete anything from the path.    ###
###                                              ###
### You may specify more than one path per       ###
### device, but not per line!  For example:      ###
###                                              ###
###   dynamic[0]="/dev/hda1 /glftpd/site/mp3 45" ###
###   dynamic[1]="/dev/hda1 /glftpd/site/vcd 45" ###
###                                              ###
### is fine, but                                 ###
###                                              ###
###   dynamic[0]="/dev/hda1 /glftpd/site/mp3 /glftpd/site/vcd 90" ###
###                                              ###
### is not!                                      ###
###                                              ###
### For each dynamic path, specify paths that    ###
### reside on the same device as the dynamic     ###
### path, but not *within* the dynamic path      ###
### itself.  This is so that the percentage of   ###
### used space is calculated correctly.          ###
###                                              ###
### You can specify multiple paths per           ###
### dynamic_subtract variable, i.e.              ###
###                                              ###
### NOTE: Do not specify other dynamic paths as  ###
###       dynamic_subtract paths                 ###
###                                              ###
### dynamic_subtract[0]="/glftpd/site/one /glftpd/site/two"
###                                              ###
### is fine.                                     ###
###                                              ###
dynamic[0]="/dev/ar0s1 /jail/glftpd/site/mp3/incoming 95"
dynamic_subtract[0]="/jail/glftpd/site/requests /jail/glftpd/site/mp3/audiobooks /jail/glftpd/site/mp3/groups"

dynamic[1]="/dev/ad0s1h /jail/glftpd/site/mv 95"
dynamic_subtract[1]="/jail/glftpd/site/mv/groups"


### DELETE-BY-DATE PATHS                         ###
###   Syntax: <path> <age limit in days>         ###
###                                              ###
### *BSD USERS: This portion of the script       ###
### requires that you install sh-utils and       ###
### fileutils from your ports tree!              ###
###                                              ###
date[0]="/dev/ar0s1 /jail/glftpd/site/requests 14"


### EXCEPTIONS:                                  ###
###   Syntax: "<string1>" "<string2>" "<...>"    ###
###                                              ###
### Space separated, quoted list of strings in   ###
### dirs that are never to be deleted.           ###
###                                              ###
### NOTE: Do not use wildcards here.  Simply     ###
###       specifying "_WHATEVER" will exclude    ###
###       "*_WHATEVER*".                         ###
###                                              ###
exceptions=( "_USE_SITE_REQUEST" "_CWD" "groups" "(incomplete)-" )


### END CONFIG ###


if [ `uname` = "Linux" ];
  then
    LS="ls" DATE="date" DU="du"
  else
    LS="/usr/local/bin/gls" DATE="/usr/local/bin/gdate" DU="/usr/local/bin/gdu"
    if [ ! -f "$LS" ] || [ ! -f "$DATE" ] || [ ! -f "$DU" ]; then
      echo "This script requires GNU's versions of ls, date, and du.  Please"
      echo "install sh-utils and fileutils from your ports tree, or download"
      echo "them as part of the coreutils package available from here:"
      echo "http://www.gnu.org/software/coreutils/"
      exit 0
    fi
fi

### FREE (NON-STRICT) MODE ###

if [ ! -z "$free_limit" ]; then

index=0
while [ "$index" -lt ${#static[@]} ];
  do
    dev_item=`echo ${static["$index"]} | awk '{print $1}'`
    dev_freespace=`df -m | grep "$dev_item" | awk '{print $4}'`
    if [ "$dev_freespace" -lt "$free_limit" ]; then
    dev_list=""$dev_list"
      $dev_item"
    fi
    index=$(( $index + 1 ))
done

index=0
while [ "$index" -lt ${#dynamic[@]} ];
  do
    dev_item=`echo ${dynamic["$index"]} | awk '{print $1}'`
    dev_freespace=`df -m | grep "$dev_item" | awk '{print $4}'`
    if [ "$dev_freespace" -lt "$free_limit" ]; then
    dev_list=""$dev_list"
      $dev_item"
    fi
    index=$(( $index + 1 ))
done

index=0
while [ "$index" -lt ${#date[@]} ];
  do
    dev_item=`echo ${date["$index"]} | awk '{print $1}'`
    dev_freespace=`df -m | grep "$dev_item" | awk '{print $4}'`
    if [ "$dev_freespace" -lt "$free_limit" ]; then
    dev_list=""$dev_list"
      $dev_item"
    fi
    index=$(( $index + 1 ))
done

if [ -z "$dev_list" ];
  then
    exit 0
  else
    dev_list=`echo "$dev_list" | uniq`
fi

fi


### GLOBAL TODAY/CURRENT WEEK ###
today=`date +"$dated_day_format"`
this_week=`date +"$dated_week_format"`


### STATIC DELETE ###
index=0
while [ "$index" -lt ${#static[@]} ];
  do
    unset running_list_stat
    dev=`echo ${static["$index"]} | awk '{print $1}'`
    on_devlist=`echo "$dev_list" | grep "$dev"`
    if [[ ! -z "$free_limit" && ! -z "$on_devlist" ]] || [ -z "$free_limit" ]; then
    dir=`echo ${static["$index"]} | awk '{print $2}'`
    limit=`echo ${static["$index"]} | awk '{print $3}'`
    current_size=`$DU -ms "$dir" | awk '{print $1}' | sed -e 's/[^[:digit:]]//g'`
        while [ "$current_size" -gt "$limit" ];
	  do
            if [ "$running_list_stat" = "" ]; then
              if [[ -d "$dir"/"$today" || -d "$dir"/"$this_week" ]];
                then
                  running_list_stat=`ls -1 "$dir"`
                else
                  running_list_stat=`ls -1tr "$dir"`
              fi
	      for o in ${exceptions[@]}; do
	        running_list_stat=`echo "$running_list_stat" | grep -v "$o"`
              done
            fi
            if [ "$debug" = "YES" ];
              then
	        oldest_dir=`echo "$running_list_stat" | head -n 1`
                echo "rm -rf -- "$dir"/"$oldest_dir""
                oldest_dirsize=`$DU -ms "$dir"/"$oldest_dir" | awk '{print $1}'`
                running_list_stat=`echo "$running_list_stat" | grep -v \
                  "$oldest_dir"`
	        current_size=`echo ""$current_size"-"$oldest_dirsize"" | bc -l`
              else
                oldest_dir=`echo "$running_list_stat" | head -n 1`
	        rm -rf -- "$dir"/"$oldest_dir"
                running_list_stat=`echo "$running_list_stat" | grep -v \
                  "$oldest_dir"`
	        current_size=`$DU -ms "$dir" | awk '{print $1}' | sed -e \
	         's/[^[:digit:]]//g'`
            fi
	  done
  fi
  index=$(( $index + 1 ))
done

### DATED DELETE ###

index=0
while [ "$index" -lt ${#date[@]} ]; do

days=`echo ${date["$index"]} | awk '{print $3}'`
seconds=`echo ""$days" * 86400" | bc`
date_dir=`echo ${date["$index"]} | awk '{print $2}'`
dev=`echo ${date["$index"]} | awk '{print $1}'`
on_devlist=`echo "$dev_list" | grep "$dev"`

if [[ ! -z "$free_limit" && ! -z "$on_devlist" ]] || [ -z "$free_limit" ];
  then
    if [[ ! -d "$date_dir"/"$today" && ! -d "$date_dir"/"$this_week" ]]; then
    for dfile in "$date_dir"/*
      do
        unset exempt
        for date_exc in ${exceptions[@]}
          do
            is_datedir_exempt=`echo "$dfile" | grep "$date_exc"`
            if [ ! -z "$is_datedir_exempt" ];
              then
                exempt="YES"
            fi
        done
        if [ -z "$exempt" ];
          then
            current_gnusecs=`$DATE "+%s"`
            gnusecs=`$DATE -r "$dfile" "+%s"`
            age_sec=`echo "$current_gnusecs" - "$gnusecs" | bc`
        fi

        if [ -z "$exempt" ] && [ "$age_sec" -ge "$seconds" ];
          then
            if [ "$debug" = "YES" ];
              then
                echo "rm -rf -- "$dfile""
              else
                rm -rf -- "$dfile"
             fi
         fi
    done
  else
    if [ -d "$date_dir"/"$today" ] || [ -d "$date_dir"/"$this_week" ];
      then
        delete_days=$(( $days + 1 ))
        running_list_date=`ls -1 "$date_dir"`
        if [ -d "$date_dir"/"$today" ]; then
          current_date=`date +"$dated_day_format"`
          date_index=`$DATE --date "-"$delete_days" days" +"$dated_day_format"`
          unit="days"
        else
          current_date=`date +"$dated_week_format"`
          date_index=`$DATE --date "-"$delete_days" days" +"$dated_week_format"`
        fi
        index=0
        while [ "$current_date" != "$date_index" ];
          do
            running_list_date=`echo "$running_list_date" | grep -v "$current_date"`
            if [ "$unit" = "days" ];
              then
                current_date=`$DATE --date "-"$index" days" +"$dated_day_format"`
              else
                current_date=`$DATE --date "-"$index" days" +"$dated_week_format"`
            fi
            index=$(( $index + 1 ))
        done
        for i in ${exceptions[@]}; do
          running_list_date=`echo "$running_list_date" | grep -v "$i"`
        done
        for i in `echo "$running_list_date"`; do
          if [ "$debug" = "YES" ];
            then
              echo "rm -rf -- "$date_dir"/"$i""
            else
              rm -rf -- "$date_dir"/"$i"
          fi
        done
    fi
  fi
fi

index=$(( $index + 1 ))
done


### DYNAMIC DELETE ###

index=0
while [ "$index" -lt ${#dynamic[@]} ];
  do
    dev=`echo ${dynamic["$index"]} | awk '{print $1}'`
    on_devlist=`echo "$dev_list" | grep "$dev"`
    if [[ ! -z "$free_limit" && ! -z "$on_devlist" ]] || [ -z "$free_limit" ]; then
    dynamic_dir=`echo ${dynamic["$index"]} | awk '{print $2}'`
    allowed_percent=`echo ${dynamic["$index"]} | awk '{print $3}'`
    current_size=`du -s "$dynamic_dir" | awk '{print $1}'`
    
    drive_used=`df | grep "$dev" | awk '{print $3}'`
    drive_avail=`df | grep "$dev" | awk '{print $4}'`
    drive_size=`echo ""$drive_used"+"$drive_avail"" | bc`

    # drive size minus the dynamic subtract dirs size
    if [ ${#dynamic_subtract[@]} != "0" ]; then
      dyn_subtract_total=`du -sc ${dynamic_subtract["$index"]} | grep total | \
        awk '{print $1}'`
      drive_size=`echo ""$drive_size"-"$dyn_subtract_total"" | bc -l`
    fi
    current_percent=`echo ""$current_size"/"$drive_size"*100" | bc -l | \
      awk -F "." '{print $1}'`
    if [ "$current_percent" = "" ];
      then
        current_percent="0"
    fi
    unset running_list_dyn
    while [ "$current_percent" -gt "$allowed_percent" ];
      do
        if [ "$running_list_dyn" = "" ]; then
          if [[ -d "$dynamic_dir"/"$today" || -d "$dynamic_dir"/"$this_week" ]];
            then
              running_list_dyn=`ls -1 "$dynamic_dir"`
            else
              running_list_dyn=`ls -1tr "$dynamic_dir"`
          fi
          for u in ${exceptions[@]}; do
            running_list_dyn=`echo "$running_list_dyn" | grep -v "$u"`
          done
        fi
	if [ "$debug" = "YES" ];
	  then
            oldest_dynamic_dir=`echo "$running_list_dyn" | head -n 1`
            echo "rm -rf -- "$dynamic_dir"/"$oldest_dynamic_dir""
            running_list_dyn=`echo "$running_list_dyn" | grep -v \
              "$oldest_dynamic_dir"`
            oldest_dynamic_dir_size=`du \
              -s "$dynamic_dir"/"$oldest_dynamic_dir" | awk '{print $1}'`
             current_size=`echo ""$current_size"-"$oldest_dynamic_dir_size"" | \
               bc -l`
	  else
            oldest_dynamic_dir=`echo "$running_list_dyn" | head -n 1`
            rm -rf -- "$dynamic_dir"/"$oldest_dynamic_dir"
            running_list_dyn=`echo "$running_list_dyn" | grep -v \
              "$oldest_dynamic_dir"`
            current_size=`du -s "$dynamic_dir" | awk '{print $1}'`
	fi
        current_percent=`echo ""$current_size"/"$drive_size"*100" | bc -l | \
         awk -F "." '{print $1}'`
        # because percentages less than 1% will not show up
        if [ -z "$current_percent" ]; then
          current_percent="0"
        fi
      done
  fi
  index=$(( $index + 1 ))
done


exit 0
